@@ -1,5 +1,5 @@
 --
--- Copyright (c) 2013-2019 Nicola Bonelli <nicola@pfq.io>
+-- Copyright (c) 2013-2023 Nicola Bonelli <nicola@larthia.com>
 --
 -- This program is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -16,15 +16,16 @@
 -- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 --
 
+module CGrep.Types (
+    Offset
+  , Text8
+  , LText8
+) where
 
-module CGrep.Types where
-
-import Data.ByteString.Char8 as C
-
-type Offset     = Int
-type Offset2d   = (Int, Int)
-type OffsetLine = Int
+import Data.ByteString.Char8 as C ( ByteString )
+import Data.ByteString.Lazy.Char8 as LC ( ByteString )
+import Data.Int ( Int64 )
 
+type Offset     = Int64
 type Text8     = C.ByteString
-type Line8     = C.ByteString
-
+type LText8    = LC.ByteString
