@@ -1,5 +1,5 @@
 --
--- Copyright (c) 2013-2019 Nicola Bonelli <nicola@pfq.io>
+-- Copyright (c) 2013-2023 Nicola Bonelli <nicola@larthia.com>
 --
 -- This program is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -18,9 +18,14 @@
 
 module Reader where
 
-import Control.Monad.Trans.Reader
+import Control.Monad.Trans.Reader ( ReaderT )
 
-import Config
-import Options
+import Config ( Config )
+import Options ( Options )
 
-type OptionT = ReaderT (Config, Options)
+data Env = Env {
+    conf :: Config
+ ,  opt  :: Options
+}
+
+type ReaderIO = ReaderT Env IO
